/*
 * serio.h - serial device routines.
 *
 * Grigoriy Sitkarev, <sitkarev@unixkomi.ru>
 */
#ifndef SERIO_H_
#define SERIO_H_

typedef enum {
	SERIO_CSIZE_5,
	SERIO_CSIZE_6,
	SERIO_CSIZE_7,
	SERIO_CSIZE_8
} serio_csize_t;

typedef enum {
	SERIO_PARITY_NONE,
	SERIO_PARITY_EVEN,
	SERIO_PARITY_ODD,
} serio_parity_t;

typedef enum {
	SERIO_ONE_STOPB,
	SERIO_TWO_STOPB,
} serio_stopb_t;

typedef enum {
	SERIO_FLOW_NONE,
	SERIO_FLOW_SOFTWARE,
	SERIO_FLOW_HARDWARE,
	SERIO_FLOW_XONXOFF = SERIO_FLOW_SOFTWARE,
	SERIO_FLOW_RTSCTS = SERIO_FLOW_HARDWARE,
} serio_flow_t;

/* helper to convert string to speed_t */
speed_t serio_str2speed(const char *str);

/* open serial device */
int serio_open(const char *file, speed_t speed, serio_csize_t csize,
		serio_parity_t parity, serio_stopb_t stopbits, serio_flow_t flow);

/* close serial device */
int serio_close(int fd);

void serio_enable_lowlatency(int fd);

void serio_set_canon(int fd);
void serio_set_raw(int fd);
void serio_fd_nonblock(int fd);
void serio_fd_block(int fd);

#endif
